Crate arc_core

Crate arc_core 

Arc Core

Event sourcing primitives for the arc framework. This crate is headless and contains no web dependencies.

Features

  • Event store trait definitions
  • Aggregate trait definitions
  • Command and event bus traits
  • Projector, projection, and projection engine traits
  • Read model store trait

Modules

access_log
Access Logger
aggregate
Aggregate Module
audit
Audit Module
command_bus
Command Bus Module
event
Event Module
event_bus
Event Bus Module
event_store
Event Store Module
integrity
Integrity Chain
projection
Projection Module
read_model_store
Read Model Store
session
Session Store
snapshot
Snapshot Module

Structs

Uuid
A Universally Unique Identifier (UUID).

Traits

Deserialize
A data structure that can be deserialized from any data format supported by Serde.
Serialize
A data structure that can be serialized into any data format supported by Serde.

Derive Macros

Deserialize
Serialize