Modules
- access_
log - Access Logger
- aggregate
- Aggregate Module
- audit
- Audit Module
- command_
bus - Command Bus Module
- event
- Event Module
- event_
bus - Event Bus Module
- event_
store - Event Store Module
- integrity
- Integrity Chain
- projection
- Projection Module
- read_
model_ store - Read Model Store
- session
- Session Store
- snapshot
- Snapshot Module
Structs
- Uuid
- A Universally Unique Identifier (UUID).
Traits
- Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Serialize
- A data structure that can be serialized into any data format supported by Serde.